-----------------------------------------------------------------------------------------------
-- Client Lua Script for VRFHelper
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"
require "GroupLib"

 
-----------------------------------------------------------------------------------------------
-- VRFHelper Module Definition
-----------------------------------------------------------------------------------------------
local VRFHelper = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function VRFHelper:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function VRFHelper:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureButton, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- VRFHelper OnLoad
-----------------------------------------------------------------------------------------------
function VRFHelper:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("VRFHelper.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
	Apollo.RegisterEventHandler("Group_Invited","OnGroupInvited", self)

end

-----------------------------------------------------------------------------------------------
-- VRFHelper OnDocLoaded
-----------------------------------------------------------------------------------------------
function VRFHelper:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "VRFHelperForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
	    self.wndMain:Show(false, true)

Apollo.RegisterEventHandler("Group_JoinRequest",		"OnGroupJoinRequest", self)			-- ( name )
Apollo.RegisterEventHandler("Group_Referral",			"OnGroupReferral", self)			-- ( nMemberIndex, name )
Apollo.RegisterSlashCommand("convertgroup",             "OnGroupConvertToRaid", self)
		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)


		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- VRFHelper Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here
function VRFHelper:OnGroupInvited(strInviterName)
groupoption = 1
self.wndMain:Show(true, true)
self.wndMain:FindChild("Title"):SetText("Invite from "..strInviterName)
self.wndMain:ToFront()


--print("Invite accepted by"..strInviterName)
end

function VRFHelper:OnGroupReferral(nMemberIndex, strTarget) -- builds the invite when I receive it
	groupoption = 2
	self.wndMain:Show(true, true)
self.wndMain:FindChild("Title"):SetText("A member requests to invite "..strTarget)
self.wndMain:ToFront()
end


function VRFHelper:OnGroupJoinRequest(strInviterName) -- builds the invite when I recieve it
groupoption = 2
	self.wndMain:Show(true, true)
self.wndMain:FindChild("Title"):SetText(strInviterName.." requests to join your party.")
self.wndMain:ToFront()
end

function VRFHelper:OnGroupConvertToRaid()
local bIsLeader = GroupLib.AmILeader()
    if not GroupLib.InRaid() and bIsLeader == true then
        GroupLib.ConvertToRaid()
		Print("Group converted to Raid.")
    else
	    if GroupLib.InRaid() then
            Print("Already in raid")
		else
		    Print("You are not the leader")
        end
	end
end


-----------------------------------------------------------------------------------------------
-- VRFHelperForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function VRFHelper:OnOK()
	self.wndMain:Show(false) -- hide the window
	if groupoption == 1 then
	GroupLib.AcceptInvite()
	else
	GroupLib.AcceptRequest()
	end
	
end

-- when the Cancel button is clicked
function VRFHelper:OnCancel()
	self.wndMain:Show(false)
	if groupoption == 1 then
	GroupLib.DeclineInvite() -- hide the window
	else
	GroupLib.DenyRequest()
    end
end


-----------------------------------------------------------------------------------------------
-- VRFHelper Instance
-----------------------------------------------------------------------------------------------
local VRFHelperInst = VRFHelper:new()
VRFHelperInst:Init()
